@@ -2,7 +2,7 @@
 /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
- * Search dispatcher
+ * Services_Hatena /󥯥饹
  *
  * PHP version 5
  *
@@ -21,9 +21,9 @@
  */
 
 /**
- * @class Services_Hatena_base
+ * Services_Hatena 쥯饹
  *
- * This is basic class for using the Hatena API with PHP.
+ * Υ饹ϳƥ֥ӥѥ饹δȤʤ륯饹Ǥ.
  *
  * @category   Services
  * @package    Services_Hatena
@@ -33,35 +33,49 @@
  * @version    CVS: $Id$
  */
 class Services_Hatena_base {
+    /**
+     * Ƽ¹Դؿη̤Ǽޤ.
+     *
+     * @see getResult, getResultTotalNum
+     */
     protected $result = null;
+
+    /**
+     * ϤƤʥѥ饹֥ȤǼޤ.
+     *
+     * @see hatena_login
+     */
     protected $_login = null;
+
+    /**
+     * ϤƤʥɬפWSSEǧʸǼޤ.
+     *
+     * @see getWSSEAuth
+     */
     protected $_wsse  = null;
 
     /**
-     * @fn Services_Hatena_base
-     * @brief constructer for Services_Hatena_base class
+     * 󥹥ȥ饯
      *
      * @access  public
      */
     public function Services_Hatena_base() {}
 
     /**
-     * @fn getResult
-     * @brief i will show you the result.
+     * ̤֤ޤ
      *
      * @access  public
-     * @return  string or array result
+     * @return  string 
      */
     public function getResult() {
         return $this->result;
     }
 
     /**
-     * @fn getResultTotalNum
-     * @brief i will show you the result.
+     * ̤֤ޤ
      *
      * @access  public
-     * @return  string or array count of result
+     * @return  integer ̤Υ
      */
     public function getResultTotalNum() {
         if ( is_array($this->result) ) {
@@ -73,11 +87,10 @@ class Services_Hatena_base {
     }
 
     /**
-     * @fn hatena_login
-     * @brief you will be able to login to Hatena
+     * ϤƤʤ˥󤹤뤿δؿ
      *
-     * @param   string user name
-     * @param   string password
+     * @param   string $user 桼̾
+     * @param   string $pass ѥ
      * @access  public
      */
     public function hatena_login($user, $pass) {
@@ -86,22 +99,20 @@ class Services_Hatena_base {
     }
 
     /**
-     * @fn getWSSEAuth
-     * @brief you will be able to get WSSE certification
+     * WSSEǧѤʸ֤ޤ
      *
      * @access  public
-     * @return  string wsse.certification
+     * @return  string WSSEǧʸ
      */
     public function getWSSEAuth() {
         return $this->_wsse;
     }
 }
-?>
-<?php
+
 /**
- * login class
+ * ѥ饹
  *
- * This is basic login for using the Hatena API with PHP.
+ * Υ饹ϤϤƤʥӥ˥󤹤뤿Υ饹Ǥ
  *
  * @category   Services
  * @package    Services_Hatena
@@ -114,21 +125,19 @@ require_once 'HTTP/Request.php';
 class Services_Hatena_login extends HTTP_Request
 {
     /**
-     * @fn Services_Hatena_login
-     * @brief constructer for Services_Hatena_login class
+     * 󥹥ȥ饯
      *
      * @access  public
      */
     function Services_Hatena_login() {}
 
     /**
-     * @fn setWSSEAuth
-     * @brief you will be able to make WSSE certification
+     * WSSEǧѤʸޤ
      *
      * @access  public
-     * @param   string username
-     * @param   string password
-     * @return  string wsse.certification
+     * @param   string $user 桼̾
+     * @param   string $pass ѥ
+     * @return  string WSSEǧʸ
      */
     function setWSSEAuth($user, $pass, $sha1 = false)
     {
