@@ -2,7 +2,7 @@
 /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
- * hatena dispatcher
+ * ϤƤ ǥѥå
  *
  * PHP version 5
  *
@@ -27,10 +27,11 @@ require_once(HATENA_BASEDIR . "base.php");
 
 
 /**
- * Hatena dispatcher class
+ * ϤƤ 𴴥饹
  *
- * This class provides a method to create a concrete instance of one
- * of the supported service types (Search, AutoLink, Bookmarknum and Asin).
+ * Υ饹ϤϤƤʤΥ֥ӥAPI(,ư,֥åޡ,
+ * եȥ饤,֥åޡ,拾쥯,Ϣ۸,ϤƤexist)
+ * Ѥ뤿γƥ饹֥Ȥ뤿δ𴴥饹Ǥ.
  *
  * @category   Services
  * @package    Services_Hatena
@@ -40,35 +41,48 @@ require_once(HATENA_BASEDIR . "base.php");
  * @version    CVS: $Id$
  */
 class Services_Hatena {
-    public function __construct() {}
-    public function Services_hatena() {}
-
     /**
-     * Attempts to return a concrete instance of a class
+     * 󥹥ȥ饯.
      *
      * @access  public
-     * @param   string Type of Service. Can be one of search, autolink, asin, bookmarknum, bookmark, similar and photo
-     * @return  object Concrete instance of a service class based on the paramter
+     */
+    public function __construct() {}
+
+    /**
+     * 󥹥ȥ饯.
+     *
+     * @access  public
+     */
+    // public function Services_hatena() {}
+
+    /**
+     * ƥ饹֥Ȥ֤ޤ.
+     *
+     * 륯饹μꤷ饹֥Ȥޤ.
+     *
+     * @access  public
+     * @param   string $type 륵ӥʸꤷޤ. ʲΤΤɤ줫ǽǤ(search, autolink, asin, bookmarknum, bookmark, similar, photo, exist)
+     * @return object ˴Ť饹֥
      */
     public function create($type)
     {
 
         switch ($type) {
 
-        case "search"      : // i will make class for hatena search
-        case "autolink"    : // i will make class for autolink word
-        case "bookmarknum" : // i will make class for bookmarked count
-        case "asin"        : // i will make class for asin count
-        case "similar"     : // i will make class for similar word
-        case "bookmark"    : // i will make class for bookmark operate
-        case "photo"       : // i will make class for photo operate
-        case "exist"       : // i will make class for exist operate
+        case "search"      : // APIѤ뤿Υ饹Ǥ
+        case "autolink"    : // ưAPIѤ뤿Υ饹Ǥ
+        case "bookmarknum" : // ֥åޡAPIѤ뤿Υ饹Ǥ
+        case "asin"        : // 拾쥯APIѤ뤿Υ饹Ǥ
+        case "similar"     : // Ϣ۸APIѤ뤿Υ饹Ǥ
+        case "bookmark"    : // ֥åޡAPIѤ뤿Υ饹Ǥ
+        case "photo"       : // եȥ饤APIѤ뤿Υ饹Ǥ
+        case "exist"       : // exist APIѤ뤿Υ饹Ǥ
             require_once(HATENA_BASEDIR . $type . ".php");
             $classname = "Services_Hatena_" . $type;
             return new $classname;
 
         default :
-            /** i do nothing */ 
+            // ⤷ޤ
             break;
         }
     }
